@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2006 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,68 +38,53 @@ long vzquotactl_syscall(
 	int fd;
 	struct vzctl_quotactl qu =
 	{
-	    cmd		: _cmd,
-	    quota_id	: _quota_id,
-	    qstat	: _qstat,
-	    ve_root	: (char *) _ve_root  
+	    .cmd	= _cmd,
+	    .quota_id	= _quota_id,
+	    .qstat	= _qstat,
+	    .ve_root	= (char *) _ve_root
 	};
 
 //	ASSERT(_qstat);
-	
+
 	debug(LOG_DEBUG, "vzquotactl ioctl start:cmd %d: id %d\n",
 		_cmd, _quota_id);
-	
+
 	fd = open(VZCTL_DEVICE, O_RDWR);
 	if (fd < 0)
 		error(EC_VZCALL, errno, "can't open vzctl device '%s'", VZCTL_DEVICE);
 
 	debug(LOG_DEBUG, "attempt new ioctl[%d]\n", VZCTL_QUOTA_CTL);
-#ifndef L2
-	rc = ioctl(fd, VZCTL_QUOTA_CTL, &qu);
-	if (rc < 0 && (errno == ENOTTY || errno == EINVAL))
-	{
-		/* attempt old quota syscall */
-		struct vz_quota_stat_old qstat_old = quota_new2old(_qstat);
-		debug(LOG_DEBUG, "attempt old ioctl [%d]\n", VZCTL_QUOTA_CTL_OLD);
-
-		qu.qstat = (struct vz_quota_stat *) &qstat_old;
-		rc = ioctl(fd, VZCTL_QUOTA_CTL_OLD, &qu);
-		*_qstat = quota_old2new(&qstat_old);
-	}
-#else
 	rc = ioctl(fd, VZCTL_QUOTA_NEW_CTL, &qu);
-#endif
 	debug(LOG_DEBUG, "vzquotactl ioctl end:cmd %d: id %d: status %d\n",
 		_cmd, _quota_id, rc);
-	
-	close(fd);	
+
+	close(fd);
 	return rc;
 }
 
-#ifdef L2
 long vzquotactl_ugid_syscall(
-		int _cmd,                /* subcommand */
+		int _cmd,		 /* subcommand */
 		unsigned int _quota_id,  /* quota id where it applies to */
 		unsigned int _ugid_index,/* for reading statistic. index of first
 					    uid/gid record to read */
 		unsigned int _ugid_size, /* size of ugid_buf array */
-		void *_addr               /* user-level buffer */
+		void *_addr		 /* user-level buffer */
 		)
 {
 	int rc;
 	int fd;
 	struct vzctl_quotaugidctl qu =
 	{
-		cmd		: _cmd,
-		quota_id	: _quota_id,
-		ugid_index	: _ugid_index,
-		ugid_size	: _ugid_size,
-		addr		: _addr
+		.cmd		= _cmd,
+		.quota_id	= _quota_id,
+		.ugid_index	= _ugid_index,
+		.ugid_size	= _ugid_size,
+		.addr		= _addr
 	};
 
 	debug(LOG_DEBUG, "vzquotaugidctl ioctl start:cmd %d: id %d\n",
 		_cmd, _quota_id);
-	
+
 	fd = open(VZCTL_DEVICE, O_RDWR);
 	if (fd < 0)
 		error(EC_VZCALL, errno, "can't open vzctl device '%s'", VZCTL_DEVICE);
@@ -108,11 +93,10 @@ long vzquotactl_ugid_syscall(
 
 	debug(LOG_DEBUG, "vzquotaugidctl ioctl end:cmd %d: id %d: status %d\n",
 		_cmd, _quota_id, rc);
-	
-	close(fd);	
+
+	close(fd);
 	return rc;
 }
-#endif
 
 #else
 
